/*
 * Piezo_API.h
 *
 *  Created on: Mar 4, 2014
 *      Author: Ian Cathey
 */

#ifndef PIEZO_API_H_
#define PIEZO_API_H_

#define MAX_NUM_CHANNELS	8		// number of channels on device
#define ADC_NUM_SAMPLES		16		// number of ADC samples to average
#define MAX_FAILS			1000	// maximum allowable airflow detection fails before raising a flag

#define CHAN_0				0
#define CHAN_1				1
#define CHAN_2				2
#define CHAN_3				3
#define CHAN_4				4
#define CHAN_5				5
#define CHAN_6				6
#define CHAN_7				7

/* Functions concerning ADC config */
extern void AFS_configureADC10();

/* Function concerning enabling and disabling channels */
extern void AFS_enableChannel(int channel);
extern void AFS_disableChannel(int channel);
extern unsigned int AFS_returnEnabledChannels();
extern unsigned int AFS_returnNumberChannels();
extern unsigned int AFS_returnEnabledStatus(int channel);

/* Functions concerning channel alarms */
extern void AFS_setFailLevel(int level);
extern void AFS_enableAlarmAll();
extern void AFS_disableAlarmAll();
extern void AFS_enableAlarm(int channel);
extern void AFS_disableAlarm(int channel);
extern unsigned int AFS_returnEnabledAlarms();
extern unsigned int AFS_returnAlarmEnabledStatus(int channel);
extern unsigned int AFS_returnAlarmStatus(int channel);
extern unsigned int AFS_returnAlarmStatusAll();
extern void AFS_clearAlarm(int channel);
extern void AFS_clearAlarmAll();

/* Functions concerning reading channels */
extern void AFS_monitorChannels();
extern unsigned int AFS_returnAverageReading(int channel);

/* Other functions */
unsigned int ADC_averageSamples(int channel);
void UART_resultToGUI(unsigned int result, int channel);


#endif /* PIEZO_API_H_ */
