//This program is for the SAT0020 piezo fan airflow measurer. 
//The MSP430 Launchpad takes measurements from one or more ADC channels and sends it out through uart to PC
//
// 	Engineer: Ian Cathey
// 	Date Created: March 3, 2014
// 	Texas Instruments Incorporated
//	SAT0020_Piezo_Airflow.c

//
// Includes
//
#include <msp430.h>
#include "usci_uart.h"
#include "AFS_API.h"

//
// Define statements
//


//
// Global variable definitions
//


//
// Function Prototypes
//


//
// Main Code
//
int main(void)
{
	WDTCTL = WDTPW + WDTHOLD;					//Disable Watchdog
	DCOCTL = CALDCO_16MHZ;						//Set DCO for 16MHz
	BCSCTL1 = CALBC1_16MHZ;

	/* Local Variable Definitions */

	/* Configure GPIOs */
	P1DIR |= BIT0 + BIT6;						// set P1.0 & P1.6 as outputs for LEDs
	P1DIR &= ~BIT3;								// set P1.3 as input

	/* Set Green LED on to indicate initially good status */
	P1OUT &= ~BIT0;								// turn off red LED
	P1OUT |= BIT6;								// turn on green LED

	/* Configure UART parameters */
	Setup_UART(UART_PORT_1, BIT2, BIT1, UART_SMCLK_16_MHZ, UART_9600_BAUD);

	P2SEL &= ~BIT6;				// set P2.6 to GPIO
	P2SEL2 &= ~BIT6;			// set P2.6 to GPIO
	P2DIR |= BIT6;				// set P2.6 to output pin
	P2OUT |= BIT6;				// set P2.6 high to enable op-amp on Boosterpack


	/* Enable interrupts */
	__enable_interrupt();
	

	/* Configure ADC10 */
	AFS_configureADC10();						// Set Sample & Hold time to 64 clks, and enable interrupts
	AFS_enableChannel(CHAN_3);					// Enable Channel 3

	/* Configure Alarms */
	AFS_setFailLevel(900);						// Set the fail level to Vcc/2 (this should always pass)
	AFS_enableAlarm(CHAN_3);					// Enable the Alarm for Channel 3

	while(1)
	{
		if (AFS_returnNumberChannels())				// Only act if a channel is enabled
		{
			AFS_monitorChannels();					// Sample all enabled channels

			if (AFS_returnAlarmStatusAll())			// If any alarms were raised
			{
				AFS_clearAlarmAll();				// Clear all alarms

				/* display "alarm" */
				P1OUT &= ~BIT6;						// Turn off green LED
				P1OUT |= BIT0;						// Turn on red LED
			}
			else
			{
				/* display "all good" */
				P1OUT &= ~BIT0;						// turn off red LED
				P1OUT |= BIT6;						// turn on green LED
			}
		}
	}
}

