#include <msp430.h>
#include "usci_uart.h"

static unsigned char rx_char;
static unsigned char UartFlag = 0;

                      // 9600, 19200, 38400, 76800, 115200
static unsigned int UART_ClockRates[10][5] =
{
        104, 52, 26, 13, 9,                        // 1 MHz
        208, 104, 52, 26, 17,                      // 2 MHz
        416, 108, 104, 52, 35,                     // 4 MHz
        833, 416, 208, 104, 69,                    // 8 MHz
        1666, 833, 416, 208, 139				   // 16 MHz
};

unsigned char UART_Interrupts;

void pause_UART(void)
{
    UART_Interrupts = IE2 & (UCB0RXIE |UCB0RXIE);
    IE2 &= ~(UCB0RXIE |UCB0RXIE);

}

void resume_UART(void)
{
    IE2 |= UART_Interrupts;
}

void Setup_UART (uartPort_t uartPort, unsigned char tx_pin, unsigned char rx_pin, uartSmclkSpeed_t smclkSpeed, uartClkRate_t uartClkRate)
{
#if defined __MSP430_HAS_PORT1_R__
   if (uartPort == UART_PORT_1)
   {
       P1SEL  |= tx_pin + rx_pin;           // Assign UART pins to USCI_A0
       P1SEL2  |= tx_pin + rx_pin;           // Assign UART pins to USCI_A0
   }
#endif
#if defined __MSP430_HAS_PORT2_R__
   if (uartPort == UART_PORT_2)
   {
       P2SEL  |= tx_pin + rx_pin;           // Assign UART pins to USCI_A0
       P2SEL2  |= tx_pin + rx_pin;           // Assign UART pins to USCI_A0
   }
#endif
#if defined __MSP430_HAS_PORT3_R__
   if (uartPort == UART_PORT_3)
   {
       P3SEL  |= tx_pin + rx_pin;           // Assign UART pins to USCI_A0
       P3SEL2  |= tx_pin + rx_pin;           // Assign UART pins to USCI_A0
   }
#endif
#if defined __MSP430_HAS_PORT4_R__
   if (uartPort == UART_PORT_4)
   {
       P4SEL  |= tx_pin + rx_pin;           // Assign UART pins to USCI_A0
       P4SEL2  |= tx_pin + rx_pin;           // Assign UART pins to USCI_A0
   }
#endif

	UCA0CTL1 |= (UCSWRST | UCSSEL_2);   // Use SMCLK and place UART in reset to change clocking
	UCA0BR0 = UART_ClockRates[smclkSpeed][uartClkRate] & 0xff;    
    UCA0BR1 = UART_ClockRates[smclkSpeed][uartClkRate] >> 8;    
	UCA0MCTL = UCBRS0;                  // Modulation UCBRSx = 1
	UCA0CTL1 &= ~UCSWRST;               // **Initialize USCI state machine**
	IE2 |= UCA0RXIE + UCA0TXIE;                    // Enable USCI_A0 RX+TX interrupt
	return;
}

unsigned char getUartFlag (void)
{
    return (UartFlag);
}

void uart_WaitForChar()               //Waits for a valid char from the UART
{
    UartFlag = 0;
    IE2 |= UCB0RXIE;
}

unsigned char uart_getchar()               //Gets a valid char from the UART already returned from UART
{
    UartFlag = 0;
    return rx_char;
}

unsigned char uart_getc()				//Waits for a valid char from the UART
{
    UartFlag = 0;
    IE2 |= UCB0RXIE;
    __bis_SR_register(CPUOFF + GIE);        // Enter LPM0 w/ interrupts; Wait for character to arrive

    return rx_char;
}

void uart_gets(char* Array, int length)
{
	unsigned int i = 0;

	while((i < length))					//Grab data till the array fills
	{
		Array[i] = uart_getc();
		//uart_putc(Array[i]);
		if(Array[i] == '\r')				//If we receive a \r the master wants to end
		{
			for( ; i < length ; i++)		//fill the rest of the string with \0 nul. Overwrites the \r with \0
			{
				Array[i] = '\0';
			}
			break;
		}
		i++;
	}

    return;
}

void uart_putc(unsigned char c)
{
	UCA0TXBUF=c;						// TX next character
	__bis_SR_register(CPUOFF + GIE);    // Wait till TX Buffer is empty
	return;
}


void uart_puts(char *str)				//Sends a String to the UART.
{
    while(*str) 
        uart_putc(*str++);		//Advance though string till end

    while (!(IFG2&UCA0TXIFG));  // Make sure last byte gets sent

    return;
}

#pragma vector = USCIAB0RX_VECTOR		//UART RX USCI Interrupt. This triggers when the USCI receives a char.
__interrupt void USCI0RX_ISR(void)
{

    if (IE2 & UCA0RXIE)
    {
        UartFlag = 1;
        rx_char = UCA0RXBUF;			          	   //Copy from RX buffer, in doing so we ACK the interrupt as well
        __bic_SR_register_on_exit(CPUOFF + GIE);       // Clear CPUOFF bit from 0(SR)
    }
}

#pragma vector = USCIAB0TX_VECTOR		//UART TX USCI Interrupt. This triggers when the USCI receives a char.
__interrupt void USCI0TX_ISR(void)
{

    if (IE2 & UCA0TXIE)
    {
        IFG2 &= ~UCA0TXIFG;			          	   //Copy from RX buffer, in doing so we ACK the interrupt as well
        __bic_SR_register_on_exit(CPUOFF + GIE);       // Clear CPUOFF bit from 0(SR)
    }
}
